@@ -5,8 +5,8 @@ cdata <- function(plot) {
   lapply(pieces$data, function(d) {
     plyr::ddply(d, "PANEL", function(panel_data) {
       scales <- pieces$layout$get_scales(panel_data$PANEL[1])
-      details <- plot$coordinates$train(scales)
-      plot$coordinates$transform(panel_data, details)
+      panel_params <- plot$coordinates$setup_panel_params(scales$x, scales$y)
+      plot$coordinates$transform(panel_data, panel_params)
     })
   })
 }
@@ -14,8 +14,8 @@ cdata <- function(plot) {
 pranges <- function(plot) {
   layout <- ggplot_build(plot)$layout
 
-  x_ranges <- lapply(layout$panel_scales$x, function(scale) scale$get_limits())
-  y_ranges <- lapply(layout$panel_scales$y, function(scale) scale$get_limits())
+  x_ranges <- lapply(layout$panel_scales_x, function(scale) scale$get_limits())
+  y_ranges <- lapply(layout$panel_scales_y, function(scale) scale$get_limits())
 
 
   npscales <- plot$scales$non_position_scales()
